<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class PipeDriveController extends Controller
{
    private $baseUrl;
    private $apiToken;

    public function __construct()
    {
        $this->apiToken = env('PIPEDRIVE_API_TOKEN');
        $this->baseUrl = env('PIPEDRIVE_BASE_URL');
    }

    public function getDealV2($id)
    {
        $url = "{$this->baseUrl}/api/v2/deals/{$id}";
        $params = ['api_token' => $this->apiToken];

        $response = Http::get($url, $params);

        if ($response->successful()) {
            return $response->json()['data'];
        } else {
            Log::error("Failed to retrieve deals from Pipedrive", ['response' => $response->body()]);
            return response()->json(['error' => 'Request failed'], $response->status());
        }
    }

    /**
     * Pega uma oportunidade específica do Pipedrive.
     * 
     * @param int $id Deal ID
     */
    public function getDeal($id)
    {
        $url = "{$this->baseUrl}/v1/deals/{$id}";
        $params = ['api_token' => $this->apiToken];

        $response = Http::get($url, $params);

        Log::info('JSON da oportunidade', ['JSON> ', $response->json()]);

        if ($response->successful()) {
            return $response->json()['data'];
        } else {
            Log::error("Failed to retrieve deal with ID {$id} from Pipedrive", ['response' => $response->body()]);
            return response()->json(['error' => 'Request failed'], $response->status());
        }
    }

    public function fetchNotes($dealId)
    {
        try {
            $response = Http::get("https://api.pipedrive.com/v1/notes?deal_id={$dealId}&api_token=" . env('PIPEDRIVE_API_TOKEN'));

            if ($response->successful() && isset($response->json()['data'])) {
                $notes = $response->json()['data'];
                $formattedNotes = '';

                // Itera sobre cada nota e processa
                foreach ($notes as $note) {
                    $content = $note['content'] ?? 'Sem conteúdo';
                    $formattedNotes .= "- {$content}\n";

                    // Aqui você pode adicionar qualquer lógica específica para cada nota.
                    // Por exemplo, verificar uma palavra-chave ou categoria na nota.
                    if (strpos($content, 'importante') !== false) {
                        Log::info("Nota marcada como importante: {$content}");
                    }
                }

                return trim($formattedNotes); // Remove espaços em branco finais
            }
        } catch (\Exception $e) {
            Log::error("Erro ao buscar notas para a oportunidade {$dealId}", ['message' => $e->getMessage()]);
        }

        return '';
    }


    public function fetchDealFlowActivities($dealId)
    {
        $apiUrl = "https://api.pipedrive.com/v1/deals/{$dealId}/flow?api_token=" . env('PIPEDRIVE_API_TOKEN');

        try {
            $response = Http::get($apiUrl);

            if ($response->successful() && isset($response->json()['data'])) {
                $flowData = $response->json()['data'];

                $activities = array_filter($flowData, function ($entry) {
                    return $entry['object'] === 'activity';
                });

                Log::info('Atividades filtradas do Pipedrive', ['activities' => $activities]);
                return $activities;
            }
        } catch (\Exception $e) {
            Log::error("Erro ao buscar atividades do Pipedrive para o negócio {$dealId}", ['message' => $e->getMessage()]);
        }

        return [];
    }
}
